import { useState, useEffect } from 'react'
import * as Form from '@radix-ui/react-form'
import TagSearchInput from './TagSearchInput'
import ComImageStatusSelect from './images/ComImageStatusSelect'

export default function ImageUploadForm({ 
  data, 
  setData, 
  processing, 
  errors = {}, 
  onSubmit, 
  submitButtonText = '上传图片',
  processingButtonText = '上传中...',
  showTagsField = true,
  showStatusField = false,
  isEdit = false,
  image = null,
  tags = [],
  cancelUrl = null
}) {
  const [preview, setPreview] = useState(isEdit && image?.file_url ? image.file_url : null)
  const [groupedTags, setGroupedTags] = useState({})
  
  // 使用控制器返回的所有标签数据并按catalog属性分组
  useEffect(() => {
    if (Array.isArray(tags) && tags.length > 0) {
      // 按catalog属性分组标签
      const groupedByCategory = {}
      
      tags.forEach(tag => {
        const catalog = tag.catalog || ''
        if (!groupedByCategory[catalog]) {
          groupedByCategory[catalog] = []
        }
        groupedByCategory[catalog].push(tag)
      })
      
      setGroupedTags(groupedByCategory)
    }
  }, [tags])

  const handleSubmit = (e) => {
    e.preventDefault()
    onSubmit(e)
  }

  const handleFileChange = (e) => {
    const file = e.target.files[0]
    setData('file', file)
    
    if (file) {
      const reader = new FileReader()
      reader.onloadend = () => {
        setPreview(reader.result)
      }
      reader.readAsDataURL(file)
    } else {
      setPreview(null)
    }
  }

  return (
    <Form.Root className="space-y-6" onSubmit={handleSubmit}>
      <Form.Field name="title" className="space-y-2">
        <Form.Label className="block text-sm font-medium text-gray-700">
          标题
        </Form.Label>
        <Form.Control asChild>
          <input
            type="text"
            name="title"
            value={data.title}
            onChange={(e) => setData('title', e.target.value)}
            className="mt-1 focus:ring-indigo-500 focus:border-indigo-500 block w-full shadow-sm sm:text-sm border-gray-300 rounded-md"
            placeholder="输入标题"
          />
        </Form.Control>
        {errors.title && (
          <Form.Message className="text-sm text-red-600">
            {errors.title}
          </Form.Message>
        )}
      </Form.Field>

      {!isEdit && (
        <Form.Field name="file" className="space-y-2">
          <Form.Label className="block text-sm font-medium text-gray-700">
            图片
          </Form.Label>
          <div className="mt-1 flex justify-center px-6 pt-5 pb-6 border-2 border-gray-300 border-dashed rounded-md">
            <div className="space-y-1 text-center">
              {preview ? (
                <div className="mb-4">
                  <img
                    src={preview}
                    alt="Preview"
                    className="mx-auto h-64 object-contain"
                  />
                </div>
              ) : (
                <svg
                  className="mx-auto h-12 w-12 text-gray-400"
                  stroke="currentColor"
                  fill="none"
                  viewBox="0 0 48 48"
                  aria-hidden="true"
                >
                  <path
                    d="M28 8H12a4 4 0 00-4 4v20m32-12v8m0 0v8a4 4 0 01-4 4H12a4 4 0 01-4-4v-4m32-4l-3.172-3.172a4 4 0 00-5.656 0L28 28M8 32l9.172-9.172a4 4 0 015.656 0L28 28m0 0l4 4m4-24h8m-4-4v8m-12 4h.02"
                    strokeWidth={2}
                    strokeLinecap="round"
                    strokeLinejoin="round"
                  />
                </svg>
              )}
              <div className="flex text-sm text-gray-600">
                <label
                  htmlFor="file-upload"
                  className="relative cursor-pointer bg-white rounded-md font-medium text-indigo-600 hover:text-indigo-500 focus-within:outline-none focus-within:ring-2 focus-within:ring-offset-2 focus-within:ring-indigo-500"
                >
                  <span>上传图片</span>
                  <Form.Control asChild>
                    <input
                      id="file-upload"
                      name="file"
                      type="file"
                      accept="image/*"  
                      className="sr-only"
                      onChange={handleFileChange}
                    />
                  </Form.Control>
                </label>
                <p className="pl-1">或拖拽上传</p>
              </div>
              <p className="text-xs text-gray-500">
                {/* PNG, JPG, GIF up to 10MB */}
              </p>
            </div>
          </div>
          {errors.file && (
            <Form.Message className="text-sm text-red-600">
              {errors.file}
            </Form.Message>
          )}
        </Form.Field>
      )}
      
      {isEdit && image && (
        <div className="mb-6">
          <img
            src={image.file_url}
            alt={image.title}
            className="max-h-64 mx-auto object-contain"
          />
        </div>
      )}
      {
        showStatusField && (
          <Form.Field name="status" className="space-y-2">
            <ComImageStatusSelect
              value={data.status}
              onChange={(value) => setData('status', value)}
              allowAll={false}
            />
          </Form.Field>
        )
      }
      {showTagsField && (
        <Form.Field name="tags" className="space-y-2">
          <Form.Label className="block text-sm font-medium text-gray-700">
            标签
          </Form.Label>
            <Form.Control asChild>
              <TagSearchInput
                value={data.tag_ids || []}
                onChange={(value) => setData('tag_ids', value)}
                allTags={groupedTags}
                placeholder="点击搜索图标添加标签"
              />
            </Form.Control>
        
        </Form.Field>
      )}

      <div className="flex justify-end space-x-3">
        {cancelUrl && (
          <a
            href={cancelUrl}
            className="bg-white py-2 px-4 border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
          >
            取消
          </a>
        )}
        <Form.Submit asChild>
          <button
            type="submit"
            disabled={processing}
            className="inline-flex justify-center py-2 px-4 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-indigo-600 hover:bg-indigo-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500 disabled:opacity-50"
          >
            {processing ? processingButtonText : submitButtonText}
          </button>
        </Form.Submit>
      </div>
    </Form.Root>
  )
}
