import React, { useState, useEffect } from 'react'
import * as Popover from '@radix-ui/react-popover'

export default function TagSelector({ availableTags = [], selectedTags = [], onChange, disabled = false }) {
  const [searchQuery, setSearchQuery] = useState('')
  const [filteredTags, setFilteredTags] = useState(availableTags)
  
  useEffect(() => {
    if (searchQuery) {
      setFilteredTags(
        availableTags.filter(tag => 
          tag.name.toLowerCase().includes(searchQuery.toLowerCase())
        )
      )
    } else {
      setFilteredTags(availableTags)
    }
  }, [searchQuery, availableTags])

  const handleSelectTag = (tag) => {
    if (!selectedTags.some(t => t.id === tag.id)) {
      const newSelectedTags = [...selectedTags, tag]
      onChange(newSelectedTags)
    }
    setSearchQuery('')
  }

  const handleRemoveTag = (tagId) => {
    const newSelectedTags = selectedTags.filter(tag => tag.id !== tagId)
    onChange(newSelectedTags)
  }

  return (
    <div className="space-y-2">
      <div className="flex flex-wrap gap-2 min-h-[2.5rem] p-2 border border-gray-300 rounded-md bg-white">
        {selectedTags.length === 0 && (
          <div className="text-gray-400 text-sm">No tags selected</div>
        )}
        
        {selectedTags.map(tag => (
          <div 
            key={tag.id} 
            className="flex items-center bg-indigo-100 text-indigo-800 text-sm rounded-full px-3 py-1"
          >
            <span>{tag.name}</span>
            {!disabled && (
              <button
                type="button"
                onClick={() => handleRemoveTag(tag.id)}
                className="ml-1.5 text-indigo-600 hover:text-indigo-800 focus:outline-none"
              >
                <span className="sr-only">Remove tag {tag.name}</span>
                <svg className="h-3.5 w-3.5" fill="currentColor" viewBox="0 0 20 20" xmlns="http://www.w3.org/2000/svg">
                  <path fillRule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zM8.707 7.293a1 1 0 00-1.414 1.414L8.586 10l-1.293 1.293a1 1 0 101.414 1.414L10 11.414l1.293 1.293a1 1 0 001.414-1.414L11.414 10l1.293-1.293a1 1 0 00-1.414-1.414L10 8.586 8.707 7.293z" clipRule="evenodd" />
                </svg>
              </button>
            )}
          </div>
        ))}
      </div>

      {!disabled && (
        <Popover.Root>
          <Popover.Trigger asChild>
            <button
              type="button"
              className="inline-flex items-center px-3 py-2 border border-gray-300 shadow-sm text-sm leading-4 font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
            >
              Add Tags
              <svg className="ml-2 -mr-0.5 h-4 w-4" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20" fill="currentColor">
                <path fillRule="evenodd" d="M5.293 7.293a1 1 0 011.414 0L10 10.586l3.293-3.293a1 1 0 111.414 1.414l-4 4a1 1 0 01-1.414 0l-4-4a1 1 0 010-1.414z" clipRule="evenodd" />
              </svg>
            </button>
          </Popover.Trigger>
          <Popover.Portal>
            <Popover.Content 
              className="bg-white rounded-md shadow-lg p-4 w-72"
              sideOffset={5}
            >
              <div className="space-y-4">
                <div>
                  <label htmlFor="tag-search" className="sr-only">
                    Search tags
                  </label>
                  <input
                    type="text"
                    id="tag-search"
                    className="block w-full border-gray-300 rounded-md shadow-sm focus:ring-indigo-500 focus:border-indigo-500 sm:text-sm"
                    placeholder="Search tags..."
                    value={searchQuery}
                    onChange={(e) => setSearchQuery(e.target.value)}
                  />
                </div>
                
                <div className="max-h-60 overflow-y-auto">
                  {filteredTags.length > 0 ? (
                    <div className="space-y-1">
                      {filteredTags.map(tag => {
                        const isSelected = selectedTags.some(t => t.id === tag.id)
                        return (
                          <button
                            key={tag.id}
                            type="button"
                            onClick={() => handleSelectTag(tag)}
                            disabled={isSelected}
                            className={`w-full text-left px-3 py-2 text-sm rounded-md ${
                              isSelected
                                ? 'bg-indigo-100 text-indigo-800 cursor-not-allowed'
                                : 'text-gray-700 hover:bg-gray-100'
                            }`}
                          >
                            {tag.name}
                          </button>
                        )
                      })}
                    </div>
                  ) : (
                    <div className="text-center py-4 text-sm text-gray-500">
                      {searchQuery ? 'No matching tags found' : 'No available tags'}
                    </div>
                  )}
                </div>
              </div>
              <Popover.Arrow className="fill-white" />
            </Popover.Content>
          </Popover.Portal>
        </Popover.Root>
      )}
    </div>
  )
}
